/**
 * vue-inertia-composable
 *
 * @description Inertia for Vue2 Composition API.
 * @author Logue <logue@hotmail.co.jp>
 * @copyright 2022 By Masashi Yoshikawa All rights reserved.
 * @license MIT
 * @version 0.3.3
 * @see {@link https://github.com/logue/vue-inertia-composable}
 */

var InertiaComposable = (function (exports, vueDemi, ziggy, inertia) {
  'use strict';

  const _interopDefaultLegacy = e => e && typeof e === 'object' && 'default' in e ? e : { default: e };

  const ziggy__default = /*#__PURE__*/_interopDefaultLegacy(ziggy);

  const InertiaLink = vueDemi.defineComponent({
    name: "InertiaLink",
    props: {
      as: {
        type: String,
        default: "a"
      },
      data: {
        type: Object,
        default: () => {
        }
      },
      href: {
        type: String,
        default: ""
      },
      method: {
        type: String,
        default: "get"
      },
      replace: {
        type: Boolean,
        default: false
      },
      preserveScroll: {
        type: Boolean,
        default: false
      },
      preserveState: {
        type: Boolean,
        default: false
      },
      only: {
        type: Array,
        default: () => []
      },
      headers: {
        type: Object,
        default: () => {
        }
      },
      queryStringArrayFormat: {
        type: String,
        default: "brackets"
      }
    },
    setup(_props, { slots, attrs }) {
      return (props) => {
        const as = props.as.toLowerCase();
        const method = props.method.toLowerCase();
        const [href, data] = inertia.mergeDataIntoQueryString(
          method,
          props.href || "",
          props.data,
          props.queryStringArrayFormat
        );
        if (as === "a" && method !== "get") {
          console.warn(
            `Creating POST/PUT/PATCH/DELETE <a> links is discouraged as it causes "Open Link in New Tab/Window" accessibility issues.

Please specify a more appropriate element using the "as" attribute. For example:

<inertia-link href="${href}" method="${method}" as="button">...</inertia-link>`
          );
        }
        return vueDemi.h(
          props.as,
          {
            ...attrs,
            ...as === "a" ? { href } : {},
            onClick: (event) => {
              if (inertia.shouldIntercept(event)) {
                event.preventDefault();
                inertia.Inertia.visit(href, {
                  data,
                  method,
                  replace: props.replace,
                  preserveScroll: props.preserveScroll,
                  preserveState: props.preserveState ?? method !== "get",
                  only: props.only,
                  headers: props.headers,
                  onCancelToken: attrs.onCancelToken || (() => void 0),
                  onBefore: attrs.onBefore || (() => void 0),
                  onStart: attrs.onStart || (() => void 0),
                  onProgress: attrs.onProgress || (() => void 0),
                  onFinish: attrs.onFinish || (() => void 0),
                  onCancel: attrs.onCancel || (() => void 0),
                  onSuccess: attrs.onSuccess || (() => void 0),
                  onError: attrs.onError || (() => void 0)
                });
              }
            }
          },
          slots
        );
      };
    }
  });
  const installInertiaLink = (app) => app.component("InertiaLink", InertiaLink);
  if (typeof window !== "undefined" && window.Vue) {
    window.Vue.use(InertiaLink);
  }

  function useHeadManager() {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$headManager;
    } else {
      warn();
    }
    return void 0;
  }
  function usePage() {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$page;
    } else {
      warn();
    }
    return void 0;
  }
  function useInertia() {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$inertia;
    } else {
      warn();
    }
    return void 0;
  }
  function useForm(args) {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.$inertia.form(args);
    } else {
      warn();
    }
    return void 0;
  }
  function route(name, params, absolute, config) {
    const instance = vueDemi.getCurrentInstance();
    if (instance) {
      return instance.proxy.route(name, params, absolute, config);
    }
    return ziggy__default.default(name, params, absolute, config);
  }
  const warn = () => console.warn(
    `[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`
  );
  if (typeof window !== "undefined") {
    window.route = route;
  }

  exports.InertiaLink = InertiaLink;
  exports.install = installInertiaLink;
  exports.route = route;
  exports.useForm = useForm;
  exports.useHeadManager = useHeadManager;
  exports.useInertia = useInertia;
  exports.usePage = usePage;

  Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

  return exports;

})({}, VueDemi, ziggy, Inertia);
